// ignore_for_file: avoid_print

import 'dart:io';

import 'package:hive_flutter/hive_flutter.dart';
import 'package:logging/logging.dart';
import 'package:path_provider/path_provider.dart';
import 'package:test/test.dart';

void main() {
  final Logger _logger = Logger('diagnostics');

  Future<bool> _pathProviderFunctionTest(String fName, Function() func) async {
    if (Platform.isMacOS) {
      await Hive.initFlutter();
    }
    bool ret = true;
    String res = '$fName:';
    try {
      res = '$res ${await func()}';
    } on UnimplementedError {
      res = '$res <Unimplemented>';
      ret = false;
    } on UnsupportedError {
      res = '$res <Unsupported>';
      ret = false;
    } on Exception catch (e) {
      res = '$res <Exception ($e)>';
      ret = false;
    } on Error catch (e) {
      res = '$res <Error ($e)>';
      ret = false;
    }
    print('*************************************************************');
    print(res);
    print('*************************************************************');
    _logger.info('path_provider support $res');
    return ret;
  }

  test('path_provider support test', () async {
    // this is a dummy test providing platform specific diagnostics
    await _pathProviderFunctionTest(
        'getDownloadsDirectory', getDownloadsDirectory);
    await _pathProviderFunctionTest('getLibraryDirectory', getLibraryDirectory);
    await _pathProviderFunctionTest(
        'getTemporaryDirectory', getTemporaryDirectory);
    await _pathProviderFunctionTest(
        'getApplicationSupportDirectory', getApplicationSupportDirectory);
    await _pathProviderFunctionTest(
        'getApplicationDocumentsDirectory', getApplicationDocumentsDirectory);
    await _pathProviderFunctionTest(
        'getApplicationDocumentsDirectory', getApplicationDocumentsDirectory);
    await _pathProviderFunctionTest(
        'getExternalStorageDirectory', getExternalStorageDirectory);
  });
  test('platform support test', () async {
    print('*************************************************************');
    print('MacOS:   ${Platform.isMacOS}');
    print('Linux:   ${Platform.isLinux}');
    print('Windows: ${Platform.isWindows}');
    print('Fuchsia: ${Platform.isFuchsia}');
    print('Fuchsia: ${Platform.isAndroid}');
    print('IOS:     ${Platform.isIOS}');
    print('*************************************************************');
    print('Hostname:${Platform.localHostname}');
    print('Version: ${Platform.version}');
  });
}
